<?php

	App::uses('CakeEventListener', 'Event');

	class OrderEmailListener implements CakeEventListener {

		public function implementedEvents() {
			return array(
				'Model.Order.orderCreated' => 'orderCreated',
				'Model.Order.orderPaid' => 'orderPaid',
				'Model.Order.orderCompleted' => 'orderCompleted',
				'Model.Order.orderFailed' => 'orderFailed',
			);
		}

		public function orderCreated() {

		}

		public function orderPaid(CakeEvent $event) {

			$this->emailConfirmation($event->data['data']['Order']['id']);

		}

		public function orderCompleted(CakeEvent $event) {

			debug('Sending request feedback/thankyou email');

		}

		public function orderFailed(CakeEvent $event) {

			//SEND FAILURE MESSAGE TO ADMIN
			throw new Exception('Failed to process payment');
			
		}

		public function emailConfirmation($orderId, $delayed = false) {

			$Order = ClassRegistry::init('EvCheckout.Order');

			$order = $Order->readForEdit($orderId);

			if (!empty($order)) {

				//Send Customer email 
				$email = new CustomEmail();

				$email->template('EvCheckout.receipt');

				$email->emailFormat('html');

				$email->to($order['Customer']['email']);
				
				$this->_configureConfirmationEmail($email, $order, $delayed);

				$email->helpers(
					array(
						'Html'
					)
				);
				
				$email->send();

				//Send Admin email 
				$email = new CustomEmail();

				$email->template('EvCheckout.admin_receipt');

				$email->emailFormat('html');

				$email->to(Configure::read('SiteSetting.orders_email'));
			
				//Email addresses to copy in such as info@evoluted.net
				if(Configure::read('EvCheckout.BlindCopyEmail')) {

					$emails = explode(",", Configure::read('EvCheckout.BlindCopyEmail'));
					foreach($emails as $emailAddress) {

						$email->addBcc(trim($emailAddress));
						
					}
				}
				
				$this->_configureConfirmationEmail($email, $order, $delayed);

				$email->subject('New Order Placed on '.Configure::read('SiteSetting.site_title'));

				$email->helpers(
					array(
						'Html'
					)
				);
				
				$email->send();

			}

		}


		protected function _configureConfirmationEmail(&$email, $order, $delayed) {
			$email->from(array(Configure::read('SiteSetting.admin_email') => Configure::read('SiteSetting.site_title')));
			$email->subject(Configure::read('SiteSetting.site_title') . ' Order Confirmation');

			$email->viewVars(
				array(
					'order' => $order,
					'delayed' => $delayed,
					'telephone' => Configure::read('SiteSetting.telephone_number')
				)
			);
			// $email->addBcc(Configure::read('SiteSetting.sales_email'));
			// $email->addBcc("8b6fcba9@trustpilotservice.com");
		}

	}
